@@ -26,5 +26,5 @@
 ===========================================================================*/
 #ifndef FLAMES_COVSRT_H
 #define FLAMES_COVSRT_H
-void covsrt(double **covar, int ma, int ia[], int mfit);
+void flames_covariance_reorder(double **covar, int ma, int* ia, int mfit);
 #endif
