@@ -135,16 +135,22 @@ try:
  
       naxis=list_hdus_sci_redl[0][0].header['NAXIS']
       if  naxis == 2  :
-          nf = list_hdus_sci_redl[0].data.shape[0]
+          nfl = list_hdus_sci_redl[0].data.shape[0]
+          nfu = list_hdus_sci_redu[0].data.shape[0]
           self.cubify = True
           print "Sci Fibre cube format"
       else :
-          nf = len(list_sci_redl)
+          nfl = len(list_sci_redl)
+          nfu = len(list_sci_redu)
           print "Sci fibre normal format"
       
       #print "nf=", nf , "cubify = ", self.cubify
 
-      self.nfibres = nf
+      # rarely happens that no same fibres are extracted on both
+      # REDL/U arms. The following trick allow the python display
+      # not to crush
+      #nf = min(nfl,nfu)
+      self.nfibres =  min(nfl,nfu)
       self.list_spec_raw = []
       self.list_snr_raw = []
       #i=1
@@ -180,7 +186,7 @@ try:
       #print self.list_obs_objects
 
       self.list_used_fibres = []
-      for i in range(nf):
+      for i in range(self.nfibres):
         #table=list_hdus_sci_info_tab_redl[0].data[i,:]
         self.red_sci_point_mos_found = True
         if self.cubify == True :
