@@ -2,6 +2,7 @@ try:
   import numpy
   import pipeline_display
   import pipeline_product
+  import platform
 except ImportError:
   donothing=1
 
@@ -37,11 +38,25 @@ class UvesBlueSpectrum:
                            self.spectrum.wave, self.spectrum.flux, 
                            autolimits=True)
     else :
-      self.specdisp.display(subplot, title, tooltip, 
-                           self.spectrum.wave, 
-                           self.spectrum.flux, self.spectrum_err.flux, 
-                           autolimits=True)
-    
+      os = platform.platform().lower()
+      mac_os="darwin" in os
+      if mac_os :
+          nwave = len(self.spectrum.flux)
+          step = int (nwave / 1300 +0.5)
+          print "nwave=",nwave,"step=",step
+          print "Mac OS: spectrum resampled every",step,"pixels"
+          self.specdisp.display(subplot, title, tooltip, 
+                                self.spectrum.wave[::step], 
+                                self.spectrum.flux[::step], 
+                                self.spectrum_err.flux[::step], 
+                                autolimits=True)
+      else :
+          print "Default OS"
+          self.specdisp.display(subplot, title, tooltip, 
+                                self.spectrum.wave, 
+                                self.spectrum.flux, self.spectrum_err.flux, 
+                                autolimits=True)
+
 class UvesRedSpectrum:
   def __init__(self, fits_low, fits_high, 
                fits_low_err = None, fits_high_err = None):
